@@ -22,20 +22,37 @@ babyphone - A baby monitor application on the Nokia N900.
 #include "settings.h"
 
 
+/*!
+  AudioLevelGraphicsScene provides specialized graphic items to display the audio
+  properties over time.
+  It gets called with each new audio sample and creates the graph. The graph 
+  already provides a line for the threshold value, which is determined by 
+  reading the application settings. Also AudioLevelGraphicsScene configures the
+  properties of the displaying QGraphicsView.
+*/
 class AudioLevelGraphicsScene : public QGraphicsScene
 {
 public:
     AudioLevelGraphicsScene(QGraphicsView *graphicsView, Settings *settings, QObject *parent);
     void AddValue(float value);
+    void Clear();
+
 
 private:
     float GetYPos(float value);
 
 
 private:
+    //! reference to global application settings
     Settings *itsSettings;
+	
+    //! actual drawing position on x-axes
     int itsCurrentPosition;
+	
+    //! total width of graphics in pixel
     int itsWidth;
+
+    //! transform factor to scale the input values into y-pixels
     float itsScale;
 };
 
